==> scala-k8s-objects_2.13-0.2.0-sources.jar: io/k8s/api/core/v1/ContainerStatus.scala <==
package io.k8s.api.core.v1


/** ContainerStatus contains details for the current status of this container. */
final case class ContainerStatus(
  name : String,
  image : String,
  restartCount : Int,
  ready : Boolean,
  imageID : String,
  state : Option[io.k8s.api.core.v1.ContainerState] = None,
  lastState : Option[io.k8s.api.core.v1.ContainerState] = None,
  containerID : Option[String] = None,
  started : Option[Boolean] = None
) {

  /** Returns a new data with name set to new value */
  def withName(value: String) : ContainerStatus = copy(name = value)
  /** transforms name to result of function */
  def mapName(f: String => String) : ContainerStatus = copy(name = f(name))

  /** Returns a new data with image set to new value */
  def withImage(value: String) : ContainerStatus = copy(image = value)
  /** transforms image to result of function */
  def mapImage(f: String => String) : ContainerStatus = copy(image = f(image))

  /** Returns a new data with restartCount set to new value */
  def withRestartCount(value: Int) : ContainerStatus = copy(restartCount = value)
  /** transforms restartCount to result of function */
  def mapRestartCount(f: Int => Int) : ContainerStatus = copy(restartCount = f(restartCount))

  /** Returns a new data with ready set to new value */
  def withReady(value: Boolean) : ContainerStatus = copy(ready = value)
  /** transforms ready to result of function */
  def mapReady(f: Boolean => Boolean) : ContainerStatus = copy(ready = f(ready))

  /** Returns a new data with imageID set to new value */
  def withImageID(value: String) : ContainerStatus = copy(imageID = value)
  /** transforms imageID to result of function */
  def mapImageID(f: String => String) : ContainerStatus = copy(imageID = f(imageID))

  /** Returns a new data with state set to new value */
  def withState(value: io.k8s.api.core.v1.ContainerState) : ContainerStatus = copy(state = Some(value))
  /** if state has a value, transforms to the result of function*/
  def mapState(f: io.k8s.api.core.v1.ContainerState => io.k8s.api.core.v1.ContainerState) : ContainerStatus = copy(state = state.map(f))

  /** Returns a new data with lastState set to new value */
  def withLastState(value: io.k8s.api.core.v1.ContainerState) : ContainerStatus = copy(lastState = Some(value))
  /** if lastState has a value, transforms to the result of function*/
  def mapLastState(f: io.k8s.api.core.v1.ContainerState => io.k8s.api.core.v1.ContainerState) : ContainerStatus = copy(lastState = lastState.map(f))

  /** Returns a new data with containerID set to new value */
  def withContainerID(value: String) : ContainerStatus = copy(containerID = Some(value))
  /** if containerID has a value, transforms to the result of function*/
  def mapContainerID(f: String => String) : ContainerStatus = copy(containerID = containerID.map(f))

  /** Returns a new data with started set to new value */
  def withStarted(value: Boolean) : ContainerStatus = copy(started = Some(value))
  /** if started has a value, transforms to the result of function*/
  def mapStarted(f: Boolean => Boolean) : ContainerStatus = copy(started = started.map(f))
}

==> scala-k8s-objects_2.13-0.4.0-sources.jar: io/k8s/api/core/v1/ContainerStatus.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** ContainerStatus contains details for the current status of this container. */
final case class ContainerStatus(
  name : String,
  image : String,
  restartCount : Int,
  ready : Boolean,
  imageID : String,
  state : Option[io.k8s.api.core.v1.ContainerState] = None,
  lastState : Option[io.k8s.api.core.v1.ContainerState] = None,
  containerID : Option[String] = None,
  started : Option[Boolean] = None
) {

  /** Returns a new data with name set to new value */
  def withName(value: String) : ContainerStatus = copy(name = value)
  /** transforms name to result of function */
  def mapName(f: String => String) : ContainerStatus = copy(name = f(name))

  /** Returns a new data with image set to new value */
  def withImage(value: String) : ContainerStatus = copy(image = value)
  /** transforms image to result of function */
  def mapImage(f: String => String) : ContainerStatus = copy(image = f(image))

  /** Returns a new data with restartCount set to new value */
  def withRestartCount(value: Int) : ContainerStatus = copy(restartCount = value)
  /** transforms restartCount to result of function */
  def mapRestartCount(f: Int => Int) : ContainerStatus = copy(restartCount = f(restartCount))

  /** Returns a new data with ready set to new value */
  def withReady(value: Boolean) : ContainerStatus = copy(ready = value)
  /** transforms ready to result of function */
  def mapReady(f: Boolean => Boolean) : ContainerStatus = copy(ready = f(ready))

  /** Returns a new data with imageID set to new value */
  def withImageID(value: String) : ContainerStatus = copy(imageID = value)
  /** transforms imageID to result of function */
  def mapImageID(f: String => String) : ContainerStatus = copy(imageID = f(imageID))

  /** Returns a new data with state set to new value */
  def withState(value: io.k8s.api.core.v1.ContainerState) : ContainerStatus = copy(state = Some(value))
  /** if state has a value, transforms to the result of function*/
  def mapState(f: io.k8s.api.core.v1.ContainerState => io.k8s.api.core.v1.ContainerState) : ContainerStatus = copy(state = state.map(f))

  /** Returns a new data with lastState set to new value */
  def withLastState(value: io.k8s.api.core.v1.ContainerState) : ContainerStatus = copy(lastState = Some(value))
  /** if lastState has a value, transforms to the result of function*/
  def mapLastState(f: io.k8s.api.core.v1.ContainerState => io.k8s.api.core.v1.ContainerState) : ContainerStatus = copy(lastState = lastState.map(f))

  /** Returns a new data with containerID set to new value */
  def withContainerID(value: String) : ContainerStatus = copy(containerID = Some(value))
  /** if containerID has a value, transforms to the result of function*/
  def mapContainerID(f: String => String) : ContainerStatus = copy(containerID = containerID.map(f))

  /** Returns a new data with started set to new value */
  def withStarted(value: Boolean) : ContainerStatus = copy(started = Some(value))
  /** if started has a value, transforms to the result of function*/
  def mapStarted(f: Boolean => Boolean) : ContainerStatus = copy(started = started.map(f))
}

object ContainerStatus {

    implicit val encoder : Encoder[io.k8s.api.core.v1.ContainerStatus] = new Encoder[io.k8s.api.core.v1.ContainerStatus] {
        def apply[T : Builder](o: io.k8s.api.core.v1.ContainerStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("name", o.name)
            .write("image", o.image)
            .write("restartCount", o.restartCount)
            .write("ready", o.ready)
            .write("imageID", o.imageID)
            .write("state", o.state)
            .write("lastState", o.lastState)
            .write("containerID", o.containerID)
            .write("started", o.started)
            .build
        }
    }

    implicit val decoder: Decoder[ContainerStatus] = new Decoder[ContainerStatus] {
      def apply[T : Reader](t: T): Either[String, ContainerStatus] = for {
          obj <- ObjectReader(t)
          name <- obj.read[String]("name")
          image <- obj.read[String]("image")
          restartCount <- obj.read[Int]("restartCount")
          ready <- obj.read[Boolean]("ready")
          imageID <- obj.read[String]("imageID")
          state <- obj.readOpt[io.k8s.api.core.v1.ContainerState]("state")
          lastState <- obj.readOpt[io.k8s.api.core.v1.ContainerState]("lastState")
          containerID <- obj.readOpt[String]("containerID")
          started <- obj.readOpt[Boolean]("started")
      } yield ContainerStatus (
          name = name,
          image = image,
          restartCount = restartCount,
          ready = ready,
          imageID = imageID,
          state = state,
          lastState = lastState,
          containerID = containerID,
          started = started
        )
    }
}
